# Changelog

## 0.6.0

- Require Python 3.8.1+.
- Remove `__version__` property.


## 0.5.0

- Require Python 3
- Replace lace with lacecore.
- Add `triangulate` option to recipes to support meshes with mixed arities.
